@@ -3,7 +3,7 @@ var searchData=
   ['camera_2eh_0',['camera.h',['../camera_8h.html',1,'']]],
   ['camera_5fcontrols_2eh_1',['camera_controls.h',['../camera__controls_8h.html',1,'']]],
   ['camera_5flens_2eh_2',['camera_lens.h',['../camera__lens_8h.html',1,'']]],
-  ['camera_5fmanager_2eh_3',['camera_manager.h',['../internal_2camera__manager_8h.html',1,'(Global Namespace)'],['../camera__manager_8h.html',1,'(Global Namespace)']]],
+  ['camera_5fmanager_2eh_3',['camera_manager.h',['../camera__manager_8h.html',1,'(Global Namespace)'],['../internal_2camera__manager_8h.html',1,'(Global Namespace)']]],
   ['camera_5fsensor_2eh_4',['camera_sensor.h',['../camera__sensor_8h.html',1,'']]],
   ['camera_5fsensor_5fhelper_2eh_5',['camera_sensor_helper.h',['../camera__sensor__helper_8h.html',1,'']]],
   ['camera_5fsensor_5fproperties_2eh_6',['camera_sensor_properties.h',['../camera__sensor__properties_8h.html',1,'']]],
